# Sustainable Masonry Wall – Force-Displacement Analysis

This repository provides a minimal and reproducible code example for generating a force-displacement curve from experimental data of a sustainable masonry wall built using LC3-based mortar. The goal is to demonstrate the curve generation process based on raw test data.

---

## Context

This work is part of a broader research project focused on the mechanical and seismic behavior of innovative sustainable masonry structures using LC3 (Limestone Calcined Clay Cement) mortar. The analysis shown here focuses on the shear response of a wall panel tested under lateral loading.

The force-displacement curve is generated from cleaned experimental data from one wall test (specimen: **SCW_A**).

---

## Intended Audience

- Researchers in structural engineering and materials science  
- Students learning about experimental data analysis  
- Reviewers assessing code reproducibility and figure quality  

---

## Project Structure

```
project-root/
├── 01_data/
│   └── SCW_A_clean_data.csv
├── 02_code/
│   └── generate_force_displacement_plot.py
├── 03_figures/
│   └── SCW_A_force_displacement_plot.png 
└── README.md
```
---

## Sample Use Case: Generate the Figure

This example generates a shear force vs. displacement curve from cleaned experimental wall data.

### 1. Clone the repository

```bash
git clone https://github.com/JO2411/CIVIL-608.git
```


### 2. Run the script

```bash
python 02_code/generate_force_displacement_plot.py
```

This will read the data from `01_data/SCW_A_clean_data.csv` and generate a figure saved in `03_figures/SCW_A_force_displacement_plot.png`.

---

##  Output

The resulting figure illustrates the in-plane lateral load behavior of the wall specimen:

![Force-Displacement Curve](figures/SCW_A_force_displacement_plot.png)

---

## Dependencies

All required Python packages are listed below:

- `pandas`
- `numpy`
- `matplotlib`
- `os`
- `math`

---

## License

This project is licensed under the MIT License. See `LICENSE` file for details.

---

## Citation

If you use this repository or the example in your work, please cite it as follows:

```bibtex
@misc{masonry_lc3_wall,
  author = {Jakov Oreb},
  title = {Sustainable Masonry Wall – Force-Displacement Analysis},
  year = {2025},
  url = {https://github.com/JO2411/CIVIL-608.git}
}
```

---

## Acknowledgments

- Experimental data from [EESD (GIS) Lab / EPFL]  
- Part of ongoing doctoral research on sustainable masonry systems

---